#line 1 "src/freedreno/ir3/ir3_lexer.c"

#line 3 "src/freedreno/ir3/ir3_lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ir3_yy_create_buffer
#define yy_delete_buffer ir3_yy_delete_buffer
#define yy_scan_buffer ir3_yy_scan_buffer
#define yy_scan_string ir3_yy_scan_string
#define yy_scan_bytes ir3_yy_scan_bytes
#define yy_init_buffer ir3_yy_init_buffer
#define yy_flush_buffer ir3_yy_flush_buffer
#define yy_load_buffer_state ir3_yy_load_buffer_state
#define yy_switch_to_buffer ir3_yy_switch_to_buffer
#define yypush_buffer_state ir3_yypush_buffer_state
#define yypop_buffer_state ir3_yypop_buffer_state
#define yyensure_buffer_stack ir3_yyensure_buffer_stack
#define yy_flex_debug ir3_yy_flex_debug
#define yyin ir3_yyin
#define yyleng ir3_yyleng
#define yylex ir3_yylex
#define yylineno ir3_yylineno
#define yyout ir3_yyout
#define yyrestart ir3_yyrestart
#define yytext ir3_yytext
#define yywrap ir3_yywrap
#define yyalloc ir3_yyalloc
#define yyrealloc ir3_yyrealloc
#define yyfree ir3_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define ir3_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer ir3_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define ir3_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer ir3_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define ir3_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer ir3_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define ir3_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string ir3_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define ir3_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes ir3_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define ir3_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer ir3_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define ir3_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer ir3_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define ir3_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state ir3_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define ir3_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer ir3_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define ir3_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state ir3_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define ir3_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state ir3_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define ir3_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack ir3_yyensure_buffer_stack
#endif

#ifdef yylex
#define ir3_yylex_ALREADY_DEFINED
#else
#define yylex ir3_yylex
#endif

#ifdef yyrestart
#define ir3_yyrestart_ALREADY_DEFINED
#else
#define yyrestart ir3_yyrestart
#endif

#ifdef yylex_init
#define ir3_yylex_init_ALREADY_DEFINED
#else
#define yylex_init ir3_yylex_init
#endif

#ifdef yylex_init_extra
#define ir3_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra ir3_yylex_init_extra
#endif

#ifdef yylex_destroy
#define ir3_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy ir3_yylex_destroy
#endif

#ifdef yyget_debug
#define ir3_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug ir3_yyget_debug
#endif

#ifdef yyset_debug
#define ir3_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug ir3_yyset_debug
#endif

#ifdef yyget_extra
#define ir3_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra ir3_yyget_extra
#endif

#ifdef yyset_extra
#define ir3_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra ir3_yyset_extra
#endif

#ifdef yyget_in
#define ir3_yyget_in_ALREADY_DEFINED
#else
#define yyget_in ir3_yyget_in
#endif

#ifdef yyset_in
#define ir3_yyset_in_ALREADY_DEFINED
#else
#define yyset_in ir3_yyset_in
#endif

#ifdef yyget_out
#define ir3_yyget_out_ALREADY_DEFINED
#else
#define yyget_out ir3_yyget_out
#endif

#ifdef yyset_out
#define ir3_yyset_out_ALREADY_DEFINED
#else
#define yyset_out ir3_yyset_out
#endif

#ifdef yyget_leng
#define ir3_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng ir3_yyget_leng
#endif

#ifdef yyget_text
#define ir3_yyget_text_ALREADY_DEFINED
#else
#define yyget_text ir3_yyget_text
#endif

#ifdef yyget_lineno
#define ir3_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno ir3_yyget_lineno
#endif

#ifdef yyset_lineno
#define ir3_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno ir3_yyset_lineno
#endif

#ifdef yywrap
#define ir3_yywrap_ALREADY_DEFINED
#else
#define yywrap ir3_yywrap
#endif

#ifdef yyalloc
#define ir3_yyalloc_ALREADY_DEFINED
#else
#define yyalloc ir3_yyalloc
#endif

#ifdef yyrealloc
#define ir3_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc ir3_yyrealloc
#endif

#ifdef yyfree
#define ir3_yyfree_ALREADY_DEFINED
#else
#define yyfree ir3_yyfree
#endif

#ifdef yytext
#define ir3_yytext_ALREADY_DEFINED
#else
#define yytext ir3_yytext
#endif

#ifdef yyleng
#define ir3_yyleng_ALREADY_DEFINED
#else
#define yyleng ir3_yyleng
#endif

#ifdef yyin
#define ir3_yyin_ALREADY_DEFINED
#else
#define yyin ir3_yyin
#endif

#ifdef yyout
#define ir3_yyout_ALREADY_DEFINED
#else
#define yyout ir3_yyout
#endif

#ifdef yy_flex_debug
#define ir3_yy_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug ir3_yy_flex_debug
#endif

#ifdef yylineno
#define ir3_yylineno_ALREADY_DEFINED
#else
#define yylineno ir3_yylineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define ir3_yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 402
#define YY_END_OF_BUFFER 403
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1229] =
    {   0,
       18,   18,  403,  401,    2,    1,  395,  396,  377,  378,
      384,  381,  383,  382,   18,   18,   18,   18,   18,   18,
      397,  401,  393,  376,  394,  401,  400,  379,  380,  352,
      400,  386,  400,  400,  400,  390,  375,  400,  400,  357,
      392,  400,  400,  353,  354,  400,  387,  356,  400,  358,
      359,  391,  400,  385,   60,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   18,    0,   19,  340,  341,
      342,  343,    0,    3,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  400,  400,  400,  400,

      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
       72,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  350,  400,
      400,  400,  400,  400,  400,  400,  349,  348,  388,  400,
      400,  400,  389,  400,  400,  400,  400,  400,  400,  400,
      400,  347,  400,  346,  400,  400,  400,  400,  400,  400,
      400,  400,  351,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  369,  400,    0,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,    0,  400,  400,  400,  400,  400,

      400,  400,  329,  400,  371,   68,  400,  400,  400,  400,
        0,    0,    0,    0,    0,    0,    8,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   45,    0,
        0,    0,    0,    0,    0,    0,   16,    0,   17,   19,
        0,    0,    0,    0,    0,   29,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  400,  400,  400,  400,  400,
      400,  332,  333,  400,  400,  311,  400,  400,   89,  400,
      400,    0,  400,  400,  400,  400,  400,  400,  361,  400,
      400,  400,  192,  107,   85,   96,  400,  400,  400,  400,
      400,  400,  211,  212,  400,   83,  400,  323,  324,  400,

      400,  400,  244,  109,  400,  400,  400,  400,  400,  400,
      400,  366,  399,  400,  400,  400,  245,  302,  234,  400,
      237,  238,  400,  400,  338,  400,  400,  368,  400,  400,
      400,  106,  400,  400,  398,  400,   71,  400,  400,    0,
        0,  400,  400,  400,    0,  400,  400,  360,  187,  400,
      400,   81,  400,  400,  188,  400,  373,   69,  327,  400,
      328,  344,  200,  110,  400,  400,  160,  400,  400,  400,
      400,  400,  191,  400,  400,  345,  307,  239,  400,  400,
      241,  242,  400,  400,  108,   70,  400,  367,  400,  400,
      325,  326,  331,  400,  400,  400,  400,  400,  400,  400,

      400,  400,  185,  400,  370,  400,    0,    0,    0,    0,
        0,    0,    0,    0,   51,    0,    0,    0,   53,    0,
       52,    0,    0,    0,    0,    9,    0,    0,    0,   41,
       40,   47,    0,    0,    0,    0,   23,    0,    0,    0,
        0,    0,    0,   30,    0,   31,   24,    0,   64,   65,
      400,    0,  400,    0,  182,  400,  400,   77,   76,  400,
      400,  400,   74,   75,   73,   78,  400,   62,   80,  400,
      400,  400,  400,   87,    0,  400,  400,  205,  400,  400,
      400,  372,  400,  400,  400,  400,   84,  190,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,

      400,  400,  339,  400,  194,  400,  400,  197,   79,   82,
        0,  299,  243,  303,  247,  319,  189,    0,  400,    0,
      400,    0,  400,  104,  400,  111,  161,    0,  400,  400,
        0,  400,  140,   66,  400,  400,  400,  400,   61,    0,
      400,  400,  400,  400,  400,  400,  400,  400,    0,  355,
        0,  201,  400,  202,    0,  400,  309,    0,  181,  179,
       98,   97,    0,  180,  178,  400,  400,  193,    0,  300,
      301,   91,   90,  248,  308,    0,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  112,  400,  400,
      400,  400,    0,    0,   93,    0,   92,    4,    5,    6,

        0,    0,    7,   15,   44,    0,    0,    0,    0,    0,
        0,    0,   43,    0,    0,    0,    0,   54,  114,  113,
        0,   16,    0,    0,    0,    0,    0,    0,    0,    0,
       26,  400,  115,  129,  128,  321,  139,    0,  400,    0,
      362,  400,  400,  400,  318,    0,  400,  150,  149,    0,
        0,  206,  400,  400,  400,  400,  400,  400,  400,  312,
        0,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  196,  195,  314,  400,  198,
      199,  235,  236,    0,    0,    0,    0,  400,  117,  137,
      136,    0,  116,  135,  134,  337,    0,  103,  400,  118,

        0,    0,    0,  400,  141,  400,  101,  100,   99,  400,
      322,  400,    0,  400,  374,  400,  400,  400,  400,  400,
      400,  400,   63,    0,  400,  203,    0,    0,    0,  158,
      151,  152,    0,  400,  240,    0,  131,  130,  230,  400,
      335,  330,  112,  400,  400,  400,  400,  400,   67,    0,
      142,    0,   10,    0,   56,   55,    0,   48,   46,    0,
        0,   59,    0,   58,    0,   22,    0,    0,    0,    0,
        0,   27,    0,  400,  153,  400,  154,    0,    0,    0,
      124,   86,  120,  133,  132,  122,  144,  143,    0,    0,
        0,  183,  184,    0,    0,  155,    0,  400,  400,  400,

      208,  400,  400,  400,  204,   95,  209,  400,  400,  305,
      400,  264,    0,    0,    0,    0,    0,    0,    0,  156,
      105,  102,    0,    0,  147,  400,  400,  400,  400,   20,
      400,  400,  249,  400,  400,  400,    0,    0,    0,    0,
      217,  218,  219,  220,    0,    0,    0,    0,    0,    0,
      119,    0,  265,    0,  400,  400,  320,  400,  400,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   32,    0,    0,  148,    0,
      159,    0,    0,    0,  221,  222,  123,  400,  400,    0,
      400,  210,   94,  207,  304,  400,  168,  169,  164,  167,

      162,  166,    0,    0,  146,  145,  400,  363,  400,  400,
       20,  400,  251,  250,  400,  223,  126,  125,  176,  177,
      170,  171,  174,  175,  172,  173,  313,  127,  364,  400,
      334,    0,    0,   42,   57,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  121,  138,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   88,  216,  215,  214,  213,  157,  400,
      400,    0,    0,  400,  246,  400,  400,    0,  224,  336,
      186,    0,    0,    0,   12,    0,    0,    0,   34,    0,
        0,    0,    0,    0,   33,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,  261,    0,    0,    0,    0,
        0,  315,  317,  316,  400,  400,  165,  163,  400,  400,
      400,  263,    0,    0,   14,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   21,  252,  260,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  256,    0,    0,    0,
        0,    0,    0,    0,    0,  255,  259,  258,    0,    0,
        0,    0,    0,    0,    0,    0,  253,    0,  262,    0,
      306,  400,  365,  400,  400,    0,   11,    0,    0,    0,
        0,   37,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  275,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,  297,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  286,    0,    0,    0,
      254,    0,  400,  400,  400,   13,    0,    0,   28,    0,
        0,   39,    0,    0,  266,  274,    0,  270,  269,  273,
      272,  267,    0,  276,    0,  288,  296,    0,  292,  291,
      295,  294,  289,    0,  298,  277,  285,    0,  281,  280,
      284,  283,  278,    0,  287,  225,  233,  400,  400,    0,
        0,    0,   36,    0,   25,    0,  268,    0,    0,  290,
        0,  279,    0,    0,  400,   50,   49,   35,   38,    0,
      257,    0,    0,    0,    0,    0,    0,    0,    0,  400,

        0,    0,    0,    0,    0,    0,    0,    0,    0,  400,
      271,  293,  282,  231,    0,    0,    0,    0,    0,  310,
      232,    0,  229,    0,  228,  226,  227,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    1,    6,    1,    1,    1,    1,    7,
        8,    1,    9,   10,   11,   12,   13,   14,   15,   16,
       17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
       27,   28,    1,   29,   30,   30,   30,   30,   31,   30,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       33,    1,   34,    1,   35,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
       60,   61,    1,   62,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[63] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
        2,    3,    1,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    5,
        6,    7,    1,    1,    7,    5,    5,    5,    5,    6,
        5,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    8,    7,
        7,    1
    } ;

static const flex_int16_t yy_base[1239] =
    {   0,
        0,    0, 1413, 1414, 1414, 1414, 1414, 1414,   55, 1414,
     1414, 1414, 1414,   26,   63,   81, 1373, 1372, 1371, 1370,
     1414, 1405, 1414, 1414, 1414,  104,    0, 1414, 1414,  119,
       82,  161,   29,   29,   70,   91,  147,  158, 1351, 1362,
      174,  183,   32,   23,   72, 1349,  226,  277,  214,  236,
        0,  322,   51, 1414, 1414, 1392,  117, 1391, 1390, 1364,
      178, 1349,   48,   86,   46,  116,   83, 1352, 1390,  218,
      131,  130, 1353, 1340,    0, 1356,  138,    0, 1414, 1414,
     1414, 1414, 1391, 1414,  108, 1343, 1356, 1335, 1341, 1339,
     1332, 1331, 1329, 1345, 1347, 1341,    0, 1370, 1369, 1326,

     1340, 1334, 1338, 1333, 1325, 1354, 1357,  116, 1319, 1316,
      114,  359, 1323, 1325, 1324, 1323,  162,  142, 1315,  206,
     1310, 1322,  177, 1305,  216,  112, 1318, 1322,    0, 1309,
     1339, 1342, 1308,  200, 1309, 1300, 1299,    0, 1341, 1293,
     1309, 1300,  310, 1305,  229, 1307, 1311, 1298, 1298, 1302,
      253,    0,  231,    0,  231, 1295, 1302,  146, 1284, 1304,
     1292, 1289,    0,  247, 1296, 1324, 1323,  217, 1298,  247,
      226,  257, 1283,  251, 1292, 1292, 1278,  358, 1278,    0,
     1308, 1287, 1310,  268, 1270,  263,  310,  189, 1284, 1270,
     1283,  347, 1284, 1259,    0, 1275, 1259, 1261, 1265, 1295,

     1298, 1295,  327,  356, 1298, 1263, 1262, 1262, 1255, 1267,
      295, 1292,  272, 1291, 1290, 1249, 1414, 1294,  280, 1293,
     1260, 1291, 1244, 1255, 1254, 1244, 1286, 1239, 1414, 1237,
     1236, 1282, 1281, 1280, 1230, 1239,  327,  317,    0,    0,
     1249, 1243, 1234, 1229, 1234, 1223, 1241, 1230, 1222, 1221,
     1216, 1224, 1229, 1213, 1212, 1221, 1257, 1232,  313, 1214,
     1218,    0,    0, 1218, 1204, 1203, 1222, 1221,    0,  354,
     1206,  358, 1212, 1203, 1208, 1209, 1219, 1211,    0, 1241,
      299, 1195,    0,    0,    0,    0, 1204, 1203, 1200, 1199,
     1211, 1210, 1194, 1193, 1188,    0, 1226,  328,  367, 1203,

     1185,  330,    0, 1196,  383, 1187, 1194, 1194, 1183, 1185,
     1198,    0,    0, 1184, 1180, 1183,    0,    0,  120, 1192,
      254,    0, 1182, 1211,    0,  276, 1214,    0, 1176, 1212,
     1183,  378, 1183,  375,    0, 1165,    0, 1208, 1165, 1181,
      384,  390, 1168, 1177,  388, 1211, 1179,    0,    0, 1155,
      413,    0, 1157,  376,    0, 1199,    0,    0,  397, 1161,
      411, 1197,  419,    0, 1196, 1154,    0, 1159,  416,  415,
      428, 1156,    0, 1164, 1148,    0,    0,  423, 1165,  409,
     1143,    0, 1162, 1187,    0,    0, 1149,    0, 1148, 1156,
      418,  427,  430, 1178,  458,  462,  465, 1153, 1143, 1148,

     1131, 1178, 1177, 1135, 1175, 1131, 1177, 1176, 1175, 1132,
     1137, 1172, 1171,  470, 1414, 1130, 1129, 1121, 1414, 1126,
     1414, 1119, 1157,  264,  474, 1414, 1137,  482, 1163, 1414,
     1414, 1414, 1154, 1153,  495, 1119, 1414, 1113, 1119, 1118,
     1114, 1127, 1104, 1414, 1113, 1414, 1414, 1121, 1414, 1414,
     1119,  464, 1104, 1120,    0, 1144, 1111,    0,    0, 1142,
      507, 1096,    0,    0,    0,    0, 1097, 1414,    0, 1097,
     1093, 1137, 1094,    0,  477, 1135, 1134, 1097, 1095, 1087,
     1085,    0, 1103, 1102, 1088, 1087,    0,    0, 1097, 1124,
     1082, 1099, 1093,  488, 1088, 1082,  497, 1081, 1079,  464,

     1084, 1111,    0, 1110,    0, 1068, 1087,  462,    0,    0,
      471,    0, 1111,    0,    0,    0,    0,  494, 1079,  495,
     1109,  498, 1081,  424, 1065,    0,    0,  499, 1106, 1068,
     1079, 1075, 1414, 1414,  501, 1074, 1058, 1077, 1414, 1097,
     1066, 1060, 1072, 1059, 1057,  494, 1044, 1064,  499,    0,
     1049,    0,  460,    0,  524, 1054,    0, 1064,    0,    0,
        0,    0, 1063,    0,    0, 1087, 1047,    0, 1061,    0,
     1084,    0,    0,    0,    0,  508, 1038, 1056, 1054, 1076,
     1071, 1074, 1069, 1072, 1067, 1070, 1067, 1049, 1033, 1044,
     1039, 1029,  508, 1043,    0, 1041,    0, 1414, 1414, 1414,

     1035, 1068, 1414, 1414, 1414, 1035, 1066, 1065, 1018, 1063,
     1062, 1062, 1414, 1024, 1059, 1022, 1057, 1414, 1414, 1414,
      561,    0, 1026, 1008, 1002,  522, 1023, 1013, 1017, 1018,
     1414, 1015, 1414, 1414, 1414,    0, 1414, 1019, 1017, 1013,
        0, 1041, 1040, 1039,    0, 1009, 1003, 1414, 1414,  532,
      533,    0, 1036, 1035, 1034, 1007, 1006, 1031, 1030,    0,
     1004, 1028,  986,  985,  982,  995,  998,  993,  979,  993,
      991,  976,  968,  984,  988,    0,    0,    0,  982,    0,
        0, 1414, 1414,  988,  560,  564,  566, 1012, 1414, 1414,
     1414,  986, 1414, 1414, 1414,    0,  969,    0,  975, 1414,

     1004, 1003,  962,  973, 1414,  961,    0,    0,    0,  960,
        0,  960,  954,  963,    0,  957,  955,  968,  959,  957,
      994,  993, 1414,  568,  576,    0,  579,  580,  583,    0,
     1414, 1414,  963,  991, 1414,  965, 1414, 1414,    0,  989,
        0,  558,    0,  983,  946,  952,  948,  956, 1414,  957,
     1414,  978, 1414,  951, 1414, 1414,  954, 1414, 1414,  569,
      942, 1414,  941, 1414,  946,  941,  936,  936,  925,  948,
      306, 1414,  935,  970, 1414,  969, 1414,  943,  943,  941,
     1414,    0, 1414, 1414, 1414, 1414, 1414, 1414,  941,  940,
      939,    0,    0,  959,  958, 1414,  931,  931,  952,  957,

        0,  928,  917,  911,    0,    0,    0,  925,  925,    0,
      914, 1414,  942,  945,  940,  941,  938,  939,  554, 1414,
     1414,    0,  938,  937, 1414,  913,  601,  915,  909,    0,
      896,  910,    0,  899,  907,  893,  905,  904,  924,  927,
        0,    0,    0,    0,  922,  925,  920,  923,  918,  921,
     1414,  889, 1414,  894,  918,  885,    0,  892,  892,  892,
      922,  920,  919,  912,  917,  883,  882,  868,  881,  867,
      868,  869,  862,  876,  867, 1414,  572,  591, 1414,   54,
     1414,  155,  339,  358, 1414, 1414, 1414,  456,  595,  479,
      481,    0,    0,    0,    0,  498, 1414, 1414, 1414, 1414,

     1414, 1414,  528,  531, 1414, 1414,  513,    0,  558,  547,
        0,  564,    0,  593,  556,    0, 1414, 1414, 1414, 1414,
     1414, 1414, 1414, 1414, 1414, 1414, 1414, 1414,    0,  568,
        0,  552,  596, 1414, 1414,  617,  626,  594,  596,  587,
      594,  604,  606,  609,  605,  603,  591, 1414, 1414,  614,
      642,  607,  616,  645,  609,  623,  608,  650,  626,  610,
      619,  621,  622,    0,    0,    0,    0,    0, 1414,  626,
      624,  652,  653,  621,    0,  634,  624,  641,    0,    0,
     1414,  665,  672,  673, 1414,  633,  634,  648, 1414,  649,
      637,  632,  648,  639, 1414,  650,  652,  653,  657,  643,

      659,  674,  660,  640,  651, 1414,  681,  666,  661,  655,
      665, 1414, 1414, 1414,  675,  675, 1414, 1414,  673,  682,
      672, 1414,  719,  722, 1414,  688,  690,  698,  689,  699,
      703,  692,  687,  694, 1414, 1414, 1414,  705,  697,  706,
      698,  712,  696,  694,  713,  693, 1414,  716,  705,  717,
      709,  723,  707,  705,  724, 1414, 1414, 1414,  727,  716,
      728,  720,  734,  718,  716,  735, 1414,  733, 1414,  720,
        0,  725,    0,  733,  741,  774, 1414,  728,  729,  740,
      750, 1414,  735,  750,  754,  747,  753,  754,  743,  757,
      758,  738,  749, 1414,  762,  757,  748,  764,  764,  765,

      754,  768,  769,  749,  760, 1414,  773,  768,  759,  774,
      775,  764,  778,  779,  759,  770, 1414,  783,  778,  769,
     1414,  783,  770,  785,  788, 1414,  767,  768, 1414,  782,
      775, 1414,  778,  793, 1414, 1414,  774, 1414, 1414, 1414,
     1414, 1414,  792, 1414,  792, 1414, 1414,  777, 1414, 1414,
     1414, 1414, 1414,  795, 1414, 1414, 1414,  779, 1414, 1414,
     1414, 1414, 1414,  797, 1414, 1414,  828,  829,  787,  835,
      836,  805, 1414,  791, 1414,  809, 1414,  806,  811, 1414,
      812, 1414,  808,  815,  809, 1414, 1414, 1414, 1414,  812,
     1414,  813,  814,  810,  823,  809,  819,  814,  825,  816,

      825,  826,  827,  829,  823,  835,  838,  822,  823,  828,
     1414, 1414, 1414, 1414,  829,  825,  838,  837,  827,    0,
     1414,  828, 1414,  823, 1414, 1414, 1414, 1414,  882,  890,
      895,  883,  902,  903,  885,  901,  908,  909
    } ;

static const flex_int16_t yy_def[1239] =
    {   0,
     1228,    1, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1229, 1229,   16,   16,   16,   16,
     1228, 1230, 1228, 1228, 1228, 1228, 1231, 1228, 1228, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1232,   16, 1233, 1234, 1228, 1228,
     1228, 1228, 1230, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1231, 1231, 1231, 1231,

     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231,   32, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,  112, 1231,
     1231, 1231,   47, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,  143,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1235,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1236, 1231, 1231, 1231, 1231, 1231,

     1231, 1231, 1231, 1231, 1231,   52, 1231, 1231, 1231, 1231,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1232, 1233,  238, 1234,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1228, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,

     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1228,
     1228, 1231, 1231, 1231, 1228, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1235, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1236, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,

     1231, 1231, 1231, 1231, 1231, 1231, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1237, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1231, 1228, 1231, 1228, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1228, 1231, 1231,
     1231, 1231, 1231, 1231, 1228, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,

     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1228, 1231, 1231, 1231, 1231, 1231, 1231, 1228, 1231, 1228,
     1231, 1228, 1231, 1231, 1231, 1231, 1231, 1228, 1231, 1231,
     1228, 1231, 1228, 1228, 1231, 1231, 1231, 1231, 1228, 1228,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1228, 1231,
     1228, 1231, 1231, 1231, 1228, 1231, 1231, 1228, 1231, 1231,
     1231, 1231, 1228, 1231, 1231, 1231, 1231, 1231, 1228, 1231,
     1231, 1231, 1231, 1231, 1231, 1228, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1228, 1228, 1231, 1228, 1231, 1228, 1228, 1228,

     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1237,  621, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1231, 1228, 1228, 1228, 1231, 1228, 1228, 1231, 1228,
      461, 1231, 1231, 1231, 1231, 1228, 1231, 1228, 1228, 1228,
     1228, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1228, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1228, 1228, 1228, 1228, 1228, 1228, 1231, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1231, 1228, 1231, 1231, 1228,

     1228, 1228, 1228, 1231, 1228, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1228, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1231, 1228, 1228, 1231, 1231, 1228, 1228, 1228, 1231,
     1228, 1228, 1228, 1231, 1228, 1228, 1228, 1228, 1231, 1231,
     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1231, 1228, 1231, 1228, 1228, 1228, 1228,
     1228, 1231, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1231, 1231, 1228, 1228, 1228, 1228, 1231, 1231, 1231,

     1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231, 1231,
     1231, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1231, 1228, 1228, 1228, 1231, 1231, 1231, 1231, 1238,
     1231, 1231, 1231, 1231, 1231, 1231, 1228, 1228, 1228, 1228,
     1231, 1231, 1231, 1231, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1231, 1231, 1231, 1231, 1231, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1231, 1231, 1228,
     1231, 1231, 1231, 1231, 1231, 1231, 1228, 1228, 1228, 1228,

     1228, 1228, 1228, 1228, 1228, 1228, 1231,  827, 1231, 1231,
     1238, 1231, 1231, 1231, 1231, 1231, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1231, 1231,
     1231, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1231, 1231, 1231, 1231, 1231, 1228, 1231,
     1231, 1228, 1228, 1231, 1231, 1231, 1231, 1228, 1231, 1231,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,

     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1231, 1231, 1228, 1228, 1231, 1231,
     1231, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1231, 1231, 1231, 1231, 1231, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,

     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1231, 1231, 1231, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1231, 1231, 1231, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1231, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1231,

     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1231,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1231,
     1228, 1228, 1228, 1228, 1228, 1228, 1228,    0, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228
    } ;

static const flex_int16_t yy_nxt[1477] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,   10,   11,   12,
       13,   14,    4,   15,   16,   17,   18,   19,   20,   20,
       20,   20,   20,   21,   22,   23,   24,   25,   26,   27,
       27,   27,   28,   29,   27,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
       45,   46,   47,   48,   49,   50,   51,   52,   53,   27,
       27,   54,   55,  165,   73,  122,  123,  162,   56,   57,
       58,  163,   59,   74,   75,  166,  127,  128,  124,  125,
      129,  164,  126,  223,  131,  167,  132,  130,  208,  227,
       60,  960,   75,   77,   61,  228,  106,  224,  107,   62,

      209,   63,   77,   64,  210,   65,  135,   66,   67,  133,
       68,   77,   69,   70,   71,   72,  134,  108,  231,   79,
       77,   78,  109,  229,  168,  225,  136,  110,  212,  213,
      137,  511,   98,   99,  111,  226,  232,   55,   55, 1228,
       85,   86,  233,   87,   88,  138,  238,   89,  238,  270,
       90,  271,   91,   92,   93,  100,  512,  101,   94,   95,
      241,   96,  264,  242,  265,  102,  230,  103,  266,  267,
      293,  294,  104,  105,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  139,  217,  140,   69,   69,  150,
      141,   72,  279,  142,  330,  144,  113,  114,  115,  143,

      116,  961,  280,  117,  331,  145,  146,  118,  119,  277,
      120,  147,  151,  152,  287,  278,  121,  288,  155,  195,
      289,  218,  156,  153,  157,   55,  158,  219,  154,  220,
      372,  291,  159,  292,  221,  301,  160,  373,  161,  170,
      170,  170,  170,  170,  170,  170,  170,  170,  170,  302,
      200,  196,  201,  197,  282,  202,  342,  203,  345,  283,
      343,  171,  284,  172,  173,  174,  198,  175,  323,  326,
      311,  613,  324,  199,  176,   69,  312,   71,   72,  177,
      178,  179,  180,  346,  204,  347,  205,  518,  325,  327,
      318,  181,  182,  183,  319,  336,  320,  337,  614,  321,

       97,  338,  348,  322,  351,  352,  362,  349,  407,  365,
      514,  515,  184,  408,  185,  363,  186,  366,  410,  187,
      188,  416,  411,  189,  454, 1228,  417, 1228,  190,  519,
      191,  192,  193,  418,  194,  206,  206,  206,  206,  206,
      206,  206,  206,  206,  206,   97,  367,   97,   97,   97,
      368,   97,  476,  874,  455,  477,  369,  435,   97,  875,
      370,  394,  371,  309,   97,   97,  435,  395,  395,  207,
      272,  356,  356,  356,  356,  356,  356,  356,  356,  491,
      396,  396,  397,  397,  377,  962,  528,  492,  378,  463,
      379,  464,  380,  381,   97,   97,   97,  382,   97,  398,

      383,   97,  399,  465,  963,   97,   97,  395,   97,  400,
      401,  547,  466,  524,   97,  468,  468,  468,  468,  494,
      396,  529,  397,  495,  548,  525,  496,  558,  535,  497,
      536,  526,  498,  499,  569,  697,  500,  395,  698,  563,
      501,  534,  534,  534,  534,  539,  539,  539,  539,  543,
      396,  395,  397,  544,  561,  552,  545,  559,  395,  570,
      553,  572,  573,  560,  396,  554,  397,  395,  562,  564,
      395,  396,  581,  397,  582,  565,  583,  605,  584,  585,
      396,  586,  397,  396,  587,  397,  588,  615,  615,  615,
      615,  615,  615,  615,  615,  617,  617,  617,  617,  617,

      617,  617,  617,  621,  633,  621,  682,  673,  680,  681,
      725,  726,  964,  648,  674,  969,  683,  634,  606,  635,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      649,  665,  669,  970,  685,  689,  971,  719,  693,  700,
      707,  708,  972,  666,  720,  973,  670,  686,  690,  687,
      691,  694,  701,  695,  702,  709,  723,  723,  723,  723,
      727,  737,  974,  738,  728,  749,  749,  749,  749, 1228,
      768, 1228,  783,  786,  813,  769,  814,  729,  815,  816,
      817,  818,  839,  864,  840,  784,  787,  785,  788,  841,
      842,  843,  844,  845,  847,  846,  848,  849,  395,  850,

      975,  903,  976,  977,  978,  979,  980,  981,  865,  904,
      982,  396,  948,  397,  908,  908,  908,  908,  908,  908,
      908,  908,  908,  908,  984,  949,  950,  951,  952,  953,
      965,  966,  954,  985,  955,  983,  967,  986,  956,  987,
      957,  988,  989,  990,  958,  991,  993,  968,  994,  959,
      995,  996,  997,  999, 1000, 1001, 1002, 1003, 1004,  992,
     1006, 1007,  998, 1009, 1011, 1012, 1005, 1013, 1014, 1015,
     1016, 1017, 1018, 1019, 1020, 1010, 1021, 1022, 1023, 1024,
     1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032, 1034, 1035,
     1036, 1037, 1038, 1046, 1039, 1040, 1047, 1056, 1057, 1058,

     1041, 1033, 1067, 1068, 1042, 1008, 1043, 1069, 1070, 1048,
     1044, 1049, 1050, 1071, 1072, 1045, 1059, 1051, 1060, 1061,
     1073, 1052, 1074, 1053, 1062, 1075, 1076, 1054, 1063, 1077,
     1064, 1078, 1055, 1079, 1065, 1080, 1081, 1082, 1083, 1066,
     1084, 1085, 1086, 1087, 1089, 1090, 1091, 1092, 1094, 1095,
     1096, 1098, 1101, 1088, 1099, 1093, 1102, 1103, 1104, 1106,
     1107, 1108, 1097, 1112, 1100, 1110, 1105, 1113, 1114, 1115,
     1117, 1118, 1119, 1109, 1121, 1111, 1122, 1116, 1123, 1124,
     1125, 1126, 1127, 1128, 1120, 1129, 1130, 1131, 1132, 1133,
     1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143,

     1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153,
     1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163,
     1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173,
     1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183,
     1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193,
     1194, 1196, 1200, 1197, 1201, 1202, 1203, 1198, 1195, 1204,
     1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214,
     1215, 1199, 1216, 1217, 1218, 1219, 1220, 1221, 1222, 1223,
     1224, 1225, 1226, 1227,   76,   76,  237,   76,  358,   76,
       83,   83,   83,   83,   83,   83,   83,   83,   97,   97,

       97,   97,   97,  239,  386,  239,  240,  240,  240,  622,
      947,  622,  911,  911,  911,  946,  945,  944,  943,  942,
      941,  940,  939,  938,  937,  936,  935,  934,  933,  932,
      931,  930,  929,  743,  928,  927,  926,  925,  924,  923,
      922,  921,  920,  919,  918,  917,  916,  915,  914,  913,
      912,  910,  909,  907,  906,  905,  902,  901,  900,  899,
      898,  897,  896,  895,  894,  893,  892,  891,  890,  889,
      888,  887,  886,  885,  884,  883,  882,  881,  880,  879,
      878,  877,  876,  873,  872,  871,  870,  869,  868,  867,
      866,  863,  862,  861,  860,  859,  858,  857,  856,  855,

      854,  853,  852,  851,  838,  837,  836,  835,  834,  833,
      832,  831,  830,  829,  828,  827,  826,  825,  824,  823,
      822,  821,  820,  819,  812,  811,  810,  809,  808,  807,
      806,  805,  804,  803,  802,  801,  800,  799,  798,  797,
      796,  795,  794,  793,  792,  791,  790,  789,  782,  781,
      780,  779,  778,  777,  776,  775,  774,  773,  772,  771,
      770,  767,  766,  765,  764,  763,  762,  761,  760,  759,
      758,  757,  756,  755,  754,  753,  752,  751,  750,  748,
      747,  746,  745,  744,  743,  743,  743,  743,  743,  743,
      743,  742,  741,  740,  739,  736,  735,  734,  733,  732,

      731,  730,  724,  722,  721,  718,  717,  716,  715,  714,
      713,  712,  711,  710,  706,  705,  704,  703,  699,  696,
      692,  688,  684,  679,  678,  677,  676,  675,  672,  671,
      668,  667,  664,  663,  662,  661,  660,  659,  658,  657,
      656,  655,  654,  653,  652,  651,  650,  647,  646,  645,
      644,  643,  642,  640,  639,  638,  637,  636,  632,  631,
      630,  629,  628,  627,  626,  625,  624,  623,  620,  619,
      618,  616,  612,  611,  610,  609,  608,  607,  604,  603,
      602,  601,  600,  599,  598,  597,  596,  595,  594,  593,
      592,  591,  590,  589,  580,  579,  578,  577,  576,  575,

      574,  571,  568,  567,  566,  557,  556,  555,  551,  550,
      549,  546,  542,  541,  540,  538,  537,  533,  532,  531,
      530,  527,  523,  522,  521,  520,  517,  516,  513,  510,
      509,  508,  507,  506,  505,  504,  503,  502,  493,  490,
      489,  488,  487,  486,  485,  484,  483,  482,  481,  480,
      479,  478,  475,  474,  473,  472,  471,  470,  469,  467,
      462,  461,  460,  459,  458,  457,  456,  453,  452,  451,
      450,  449,  448,  447,  446,  445,  444,  443,  442,  441,
      440,  439,  438,  437,  436,  434,  433,  432,  431,  430,
      429,  428,  427,  426,  425,  424,  423,  422,  421,  420,

      419,  415,  414,  413,  412,  409,  406,  405,  404,  403,
       97,  402,  393,  392,  391,  390,  389,  388,  387,  385,
      384,  376,  375,  374,  364,  361,  360,  359,  357,  355,
      354,  353,  350,  344,  341,  340,  339,  335,  334,  333,
      332,  329,  328,  317,  316,  315,  314,  313,  310,  308,
      307,  306, 1228,  305,  304,  303,  300,  299,  298,  297,
      296,  295,  290,  286,  285,  281,  276,  275,  274,  273,
      269,  268,  263,  262,  261,  260,  259,  258,  257,  256,
      255,  254,  253,  252,  251,  250,  249,  248,  247,  246,
      245,  244,  243,   84, 1228,  236,  235,   55,  234,  222,

      216,  215,  214,  211,  169,  149,  148,   84, 1228,   82,
       81,   80, 1228,    3, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228
    } ;

static const flex_int16_t yy_chk[1477] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    9,   44,   14,   33,   33,   43,    9,    9,
        9,   43,    9,   14,   15,   44,   34,   34,   33,   33,
       34,   43,   33,   63,   35,   45,   35,   34,   53,   65,
        9,  880,   16,   15,    9,   65,   31,   63,   31,    9,

       53,    9,   15,    9,   53,    9,   36,    9,    9,   35,
        9,   16,    9,    9,    9,    9,   35,   31,   67,   16,
       16,   15,   31,   66,   45,   64,   36,   31,   57,   57,
       36,  319,   30,   30,   31,   64,   67,   72,   71,   16,
       26,   26,   67,   26,   26,   36,   77,   26,   77,  111,
       26,  111,   26,   26,   26,   30,  319,   30,   26,   26,
       85,   26,  108,   85,  108,   30,   66,   30,  108,  108,
      126,  126,   30,   30,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   37,   61,   37,   72,   71,   41,
       37,   71,  118,   37,  158,   38,   32,   32,   32,   37,

       32,  882,  118,   32,  158,   38,   38,   32,   32,  117,
       32,   38,   41,   41,  123,  117,   32,  123,   42,   49,
      123,   61,   42,   41,   42,   70,   42,   61,   41,   61,
      188,  125,   42,  125,   61,  134,   42,  188,   42,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,  134,
       50,   49,   50,   49,  120,   50,  168,   50,  170,  120,
      168,   47,  120,   47,   47,   47,   49,   47,  153,  155,
      145,  424,  153,   49,   47,   70,  145,   70,   70,   47,
       47,   47,   48,  171,   50,  171,   50,  326,  153,  155,
      151,   48,   48,   48,  151,  164,  151,  164,  424,  151,

      170,  164,  172,  151,  174,  174,  184,  172,  211,  186,
      321,  321,   48,  211,   48,  184,   48,  186,  213,   48,
       48,  219,  213,   48,  259,  238,  219,  238,   48,  326,
       48,   48,   48,  219,   48,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,  143,  187,  143,  143,  143,
      187,  143,  281,  771,  259,  281,  187,  237,  143,  771,
      187,  203,  187,  143,  143,  143,  237,  203,  298,   52,
      112,  178,  178,  178,  178,  178,  178,  178,  178,  302,
      203,  298,  203,  298,  192,  883,  334,  302,  192,  270,
      192,  270,  192,  192,  112,  112,  112,  192,  112,  204,

      192,  112,  204,  270,  884,  112,  112,  299,  112,  204,
      204,  354,  270,  332,  112,  272,  272,  272,  272,  305,
      299,  334,  299,  305,  354,  332,  305,  369,  342,  305,
      342,  332,  305,  305,  378,  524,  305,  359,  524,  371,
      305,  341,  341,  341,  341,  345,  345,  345,  345,  351,
      359,  361,  359,  351,  370,  363,  351,  369,  391,  378,
      363,  380,  380,  369,  361,  363,  361,  392,  370,  371,
      393,  391,  395,  391,  395,  371,  396,  414,  396,  397,
      392,  397,  392,  393,  397,  393,  397,  425,  425,  425,
      425,  425,  425,  425,  425,  428,  428,  428,  428,  428,

      428,  428,  428,  435,  452,  435,  511,  500,  508,  508,
      553,  553,  888,  475,  500,  890,  511,  452,  414,  452,
      461,  461,  461,  461,  461,  461,  461,  461,  461,  461,
      475,  494,  497,  891,  518,  520,  896,  546,  522,  528,
      535,  535,  903,  494,  546,  904,  497,  518,  520,  518,
      520,  522,  528,  522,  528,  535,  549,  549,  549,  549,
      555,  576,  907,  576,  555,  593,  593,  593,  593,  621,
      626,  621,  650,  651,  685,  626,  685,  555,  686,  686,
      687,  687,  724,  760,  724,  650,  651,  650,  651,  725,
      725,  725,  725,  727,  728,  727,  728,  729,  742,  729,

      909,  819,  910,  912,  914,  915,  930,  932,  760,  819,
      933,  742,  877,  742,  827,  827,  827,  827,  827,  827,
      827,  827,  827,  827,  936,  877,  878,  878,  878,  878,
      889,  889,  878,  937,  878,  933,  889,  938,  878,  939,
      878,  940,  941,  942,  878,  943,  944,  889,  945,  878,
      946,  947,  950,  951,  952,  953,  954,  955,  956,  943,
      957,  958,  950,  959,  960,  961,  956,  962,  963,  970,
      971,  972,  973,  974,  976,  959,  977,  978,  982,  983,
      984,  986,  987,  988,  990,  991,  992,  993,  994,  996,
      997,  998,  999, 1000,  999,  999, 1001, 1003, 1004, 1005,

      999,  993, 1008, 1009,  999,  958,  999, 1010, 1011, 1002,
      999, 1002, 1002, 1015, 1016,  999, 1007, 1002, 1007, 1007,
     1019, 1002, 1020, 1002, 1007, 1021, 1023, 1002, 1007, 1024,
     1007, 1026, 1002, 1027, 1007, 1028, 1029, 1030, 1031, 1007,
     1032, 1033, 1034, 1038, 1039, 1040, 1041, 1042, 1043, 1044,
     1045, 1046, 1049, 1038, 1048, 1042, 1050, 1051, 1052, 1053,
     1054, 1055, 1045, 1060, 1048, 1059, 1052, 1061, 1062, 1063,
     1064, 1065, 1066, 1055, 1068, 1059, 1070, 1063, 1072, 1074,
     1075, 1076, 1078, 1079, 1066, 1080, 1081, 1083, 1084, 1085,
     1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093, 1095, 1096,

     1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1107,
     1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116, 1118,
     1119, 1120, 1122, 1123, 1124, 1125, 1127, 1128, 1130, 1131,
     1133, 1134, 1137, 1143, 1145, 1148, 1154, 1158, 1164, 1167,
     1168, 1169, 1170, 1171, 1172, 1174, 1176, 1178, 1179, 1181,
     1183, 1184, 1185, 1184, 1190, 1192, 1193, 1184, 1183, 1194,
     1195, 1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204,
     1205, 1184, 1206, 1207, 1208, 1209, 1210, 1215, 1216, 1217,
     1218, 1219, 1222, 1224, 1229, 1229, 1232, 1229, 1235, 1229,
     1230, 1230, 1230, 1230, 1230, 1230, 1230, 1230, 1231, 1231,

     1231, 1231, 1231, 1233, 1236, 1233, 1234, 1234, 1234, 1237,
      875, 1237, 1238, 1238, 1238,  874,  873,  872,  871,  870,
      869,  868,  867,  866,  865,  864,  863,  862,  861,  860,
      859,  858,  856,  855,  854,  852,  850,  849,  848,  847,
      846,  845,  840,  839,  838,  837,  836,  835,  834,  832,
      831,  829,  828,  826,  824,  823,  818,  817,  816,  815,
      814,  813,  811,  809,  808,  804,  803,  802,  800,  799,
      798,  797,  795,  794,  791,  790,  789,  780,  779,  778,
      776,  774,  773,  770,  769,  768,  767,  766,  765,  763,
      761,  757,  754,  752,  750,  748,  747,  746,  745,  744,

      740,  736,  734,  733,  722,  721,  720,  719,  718,  717,
      716,  714,  713,  712,  710,  706,  704,  703,  702,  701,
      699,  697,  692,  688,  684,  679,  675,  674,  673,  672,
      671,  670,  669,  668,  667,  666,  665,  664,  663,  662,
      661,  659,  658,  657,  656,  655,  654,  653,  647,  646,
      644,  643,  642,  640,  639,  638,  632,  630,  629,  628,
      627,  625,  624,  623,  617,  616,  615,  614,  612,  611,
      610,  609,  608,  607,  606,  602,  601,  596,  594,  592,
      591,  590,  589,  588,  587,  586,  585,  584,  583,  582,
      581,  580,  579,  578,  577,  571,  569,  567,  566,  563,

      558,  556,  551,  548,  547,  545,  544,  543,  542,  541,
      540,  538,  537,  536,  532,  531,  530,  529,  525,  523,
      521,  519,  513,  507,  506,  504,  502,  501,  499,  498,
      496,  495,  493,  492,  491,  490,  489,  486,  485,  484,
      483,  481,  480,  479,  478,  477,  476,  473,  472,  471,
      470,  467,  462,  460,  457,  456,  454,  453,  451,  448,
      445,  443,  442,  441,  440,  439,  438,  436,  434,  433,
      429,  427,  423,  422,  420,  418,  417,  416,  413,  412,
      411,  410,  409,  408,  407,  406,  405,  404,  403,  402,
      401,  400,  399,  398,  394,  390,  389,  387,  384,  383,

      381,  379,  375,  374,  372,  368,  366,  365,  362,  360,
      356,  353,  350,  347,  346,  344,  343,  340,  339,  338,
      336,  333,  331,  330,  329,  327,  324,  323,  320,  316,
      315,  314,  311,  310,  309,  308,  307,  306,  304,  301,
      300,  297,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  282,  280,  278,  277,  276,  275,  274,  273,  271,
      268,  267,  266,  265,  264,  261,  260,  258,  257,  256,
      255,  254,  253,  252,  251,  250,  249,  248,  247,  246,
      245,  244,  243,  242,  241,  236,  235,  234,  233,  232,
      231,  230,  228,  227,  226,  225,  224,  223,  222,  221,

      220,  218,  216,  215,  214,  212,  210,  209,  208,  207,
      206,  205,  202,  201,  200,  199,  198,  197,  196,  194,
      193,  191,  190,  189,  185,  183,  182,  181,  179,  177,
      176,  175,  173,  169,  167,  166,  165,  162,  161,  160,
      159,  157,  156,  150,  149,  148,  147,  146,  144,  142,
      141,  140,  139,  137,  136,  135,  133,  132,  131,  130,
      128,  127,  124,  122,  121,  119,  116,  115,  114,  113,
      110,  109,  107,  106,  105,  104,  103,  102,  101,  100,
       99,   98,   96,   95,   94,   93,   92,   91,   90,   89,
       88,   87,   86,   83,   76,   74,   73,   69,   68,   62,

       60,   59,   58,   56,   46,   40,   39,   22,   20,   19,
       18,   17,    3, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
     1228, 1228, 1228, 1228, 1228, 1228
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
/*
 * Copyright (c) 2013 Rob Clark <robclark@freedesktop.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#line 25 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
#include <stdlib.h>
#include "util/ralloc.h"
#include "ir3/ir3.h"
#include "ir3_parser.h"

#define YY_NO_INPUT
#define YY_NO_UNPUT
#define TOKEN(t) (ir3_yylval.tok = t)
extern YYSTYPE ir3_yylval;
extern void *ir3_parser_dead_ctx;
extern char *current_line;

const char *input_buffer = NULL;
size_t input_buffer_len = 256;

/**
 * Return up to max_size chars from the current input_buffer.  Reads a new
 * line into the input_buffer if it is currently empty.
 */
static size_t yy_input(char *buf, size_t max_size)
{
  if (!input_buffer)
    current_line = malloc(input_buffer_len);

  if (!input_buffer || !strlen(input_buffer)) {
    if (getline(&current_line, &input_buffer_len, ir3_yyin) < 0) {
      if (ferror(ir3_yyin))
        fprintf(stderr, "Could not read input:\n");
    } else {
      input_buffer = current_line;
    }
  }

  size_t to_copy = MIN2(max_size, strlen(input_buffer));
  memcpy(buf, input_buffer, to_copy);
  input_buffer += to_copy;

  return to_copy;
}

#define YY_INPUT(buf, result, max_size) \
  result = yy_input(buf, max_size);


void ir3_yyset_input(FILE *f);

void ir3_yyset_input(FILE *f)
{
	YY_FLUSH_BUFFER;
	ir3_yyin = f;
	if (input_buffer)
		input_buffer = "";
}

static int parse_wrmask(const char *src)
{
	int i, num = 0;
	for (i = 0; i < 4; i++) {
		if ("xyzw"[i] == src[1]) {
			num |= (1 << i);
			src++;
		}
	}
	return num;
}

static int parse_reg(const char *str)
{
	int num = 0;
	if (str[0] == 'h') {
		str++;
		num++;
	}
	if (str[0] == 'u') {
		str++;
	}
	str++;
	if (str[0] == 't') {
		str++;
	}
	num += strtol(str, (char **)&str, 10) << 3;
	switch (str[1]) {
	case 'x': num += 0; break;
	case 'y': num += 2; break;
	case 'z': num += 4; break;
	case 'w': num += 6; break;
	default: assert(0); break;
	}
	return num;
}

#line 1549 "src/freedreno/ir3/ir3_lexer.c"
#line 1550 "src/freedreno/ir3/ir3_lexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 121 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"

#line 1769 "src/freedreno/ir3/ir3_lexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1229 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1414 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 122 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
yylineno++;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 123 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
; /* ignore whitespace */
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 124 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
yylineno++; /* ignore comments */
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 125 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 0;  return T_FLUT_0_0;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 126 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 1;  return T_FLUT_0_5;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 127 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 2;  return T_FLUT_1_0;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 128 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 3;  return T_FLUT_2_0;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 129 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 4;  return T_FLUT_E;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 130 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 5;  return T_FLUT_PI;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 131 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 6;  return T_FLUT_INV_PI;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 132 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 7;  return T_FLUT_INV_LOG2_E;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 133 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 8;  return T_FLUT_LOG2_E;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 134 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 9;  return T_FLUT_INV_LOG2_10;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 135 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 10; return T_FLUT_LOG2_10;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 136 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = 11; return T_FLUT_4_0;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 137 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.flt = strtod(yytext, NULL);       return T_FLOAT;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 138 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.flt = strtod(yytext, NULL);       return T_FLOAT;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 139 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtoul(yytext, NULL, 0);    return T_INT;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 140 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtoul(yytext, NULL, 0);    return T_HEX;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 141 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.u64 = strtoull(yytext + 4, NULL, 0); return T_RAW;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 142 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_LOCALSIZE);
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 143 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_CONST);
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 144 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_BUF);
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 145 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_UBO);
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 146 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_INVOCATIONID);
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 147 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_WGID);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 148 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_NUMWG);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 149 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_BRANCHSTACK);
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 150 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_IN);
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 151 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_OUT);
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 152 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_TEX);
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 153 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_PVTMEM);
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 154 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_LOCALMEM);
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 155 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_CONSTLEN);
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 156 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_EARLYPREAMBLE);
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 157 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_FULLNOPSTART);
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 158 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_FULLNOPEND);
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 159 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_FULLSYNCSTART);
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 160 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_A_FULLSYNCEND);
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 161 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_SY);
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 162 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_SS);
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 163 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_ABSNEG);
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 164 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_NEG);
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 165 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_ABS);
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 166 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_R);
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 167 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_LAST);
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 168 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_UL);
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 169 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_EVEN);
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 170 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_POS_INFINITY);
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 171 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_NEG_INFINITY);
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 172 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_EI);
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 173 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_JP);
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 174 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_EQ_FLAG);
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 175 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_SAT);
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 176 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_EOLM);
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 177 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_EOGM);
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 178 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_EOSTSC);
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 179 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtol(yytext+4, NULL, 10); return T_RPT;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 180 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtol(yytext+4, NULL, 10); return T_NOP;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 181 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = parse_wrmask(yytext); return T_WRMASK;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 183 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = parse_reg(yytext); return T_REGISTER;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 184 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = parse_reg(yytext); return T_CONSTANT;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 185 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = parse_reg(yytext); return T_RT;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 186 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_A0;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 187 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_A1;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 188 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = parse_reg(yytext); return T_P0;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 189 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = parse_reg(yytext); return T_UP0;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 190 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtol(yytext+1, NULL, 10); return T_W;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 191 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtol(yytext+2, NULL, 10); return T_SAMP;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 192 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtol(yytext+2, NULL, 10); return T_TEX;
	YY_BREAK
/* category 0: */
case 71:
YY_RULE_SETUP
#line 195 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_NOP);
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 196 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BR);
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 197 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BRAO);
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 198 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BRAA);
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 199 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BRAC);
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 200 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BANY);
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 201 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BALL);
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 202 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BRAX);
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 203 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_JUMP);
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 204 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CALL);
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 205 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RET);
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 206 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_KILL);
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 207 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_END);
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 208 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_EMIT);
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 209 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CUT);
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 210 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CHMASK);
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 211 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CHSH);
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 212 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_FLOW_REV);
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 213 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BKT);
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 214 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STKS);
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 215 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STKR);
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 216 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_XSET);
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 217 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_XCLR);
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 218 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETLAST);
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 219 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETONE);
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 220 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DBG);
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 221 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHPS);
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 222 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHPE);
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 223 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_PREDT);
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 224 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_PREDF);
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 225 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_PREDE);
	YY_BREAK
/* category 1: */
case 102:
YY_RULE_SETUP
#line 228 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MOVMSK);
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 229 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MOVA1);
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 230 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MOVA);
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 231 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MOVA_R);
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 232 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MOV);
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 233 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_COV);
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 234 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SWZ);
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 235 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GAT);
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 236 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SCT);
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 237 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MOVS);
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 239 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.str = yytext; return T_CAT1_TYPE_TYPE;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 241 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_MUL2);
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 242 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_DIV2);
	YY_BREAK
/* category 2: */
case 115:
YY_RULE_SETUP
#line 244 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ADD_F);
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 245 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MIN_F);
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 246 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAX_F);
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 247 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MUL_F);
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 248 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SIGN_F);
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 249 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CMPS_F);
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 250 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ABSNEG_F);
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 251 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CMPV_F);
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 252 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_FLOOR_F);
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 253 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CEIL_F);
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 254 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RNDNE_F);
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 255 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RNDAZ_F);
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 256 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_TRUNC_F);
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 257 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ADD_U);
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 258 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ADD_S);
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 259 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SUB_U);
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 260 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SUB_S);
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 261 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CMPS_U);
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 262 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CMPS_S);
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 263 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MIN_U);
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 264 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MIN_S);
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 265 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAX_U);
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 266 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAX_S);
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 267 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ABSNEG_S);
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 268 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_AND_B);
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 269 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_OR_B);
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 270 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_NOT_B);
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 271 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_XOR_B);
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 272 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CMPV_U);
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 273 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CMPV_S);
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 274 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MUL_U24);
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 275 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MUL_S24);
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 276 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MULL_U);
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 277 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BFREV_B);
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 278 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CLZ_S);
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 279 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CLZ_B);
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 280 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHL_B);
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 281 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHR_B);
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 282 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ASHR_B);
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 283 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BARY_F);
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 284 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_FLAT_B);
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 285 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MGEN_B);
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 286 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETBIT_B);
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 287 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SETRM);
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 288 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CBITS_B);
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 289 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHB);
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 290 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MSAD);
	YY_BREAK
/* category 3: */
case 162:
YY_RULE_SETUP
#line 293 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAD_U16);
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 294 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MADSH_U16);
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 295 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAD_S16);
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 296 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MADSH_M16);
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 297 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAD_U24);
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 298 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAD_S24);
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 299 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAD_F16);
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 300 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_MAD_F32);
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 301 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SEL_B16);
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 302 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SEL_B32);
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 303 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SEL_S16);
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 304 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SEL_S32);
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 305 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SEL_F16);
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 306 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SEL_F32);
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 307 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAD_S16);
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 308 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAD_S32);
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 309 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHRM);
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 310 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHLM);
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 311 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHRG);
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 312 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHLG);
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 313 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ANDG);
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 314 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DP2ACC);
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 315 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DP4ACC);
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 316 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_WMM);
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 317 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_WMM_ACCU);
	YY_BREAK
/* category 4: */
case 187:
YY_RULE_SETUP
#line 320 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RCP);
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 321 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RSQ);
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 322 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LOG2);
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 323 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_EXP2);
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 324 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SIN);
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 325 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_COS);
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 326 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SQRT);
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 327 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_HRSQ);
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 328 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_HLOG2);
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 329 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_HEXP2);
	YY_BREAK
/* category 5: */
case 197:
YY_RULE_SETUP
#line 332 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ISAM);
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 333 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ISAML);
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 334 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ISAMM);
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 335 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAM);
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 336 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAMB);
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 337 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAML);
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 338 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAMGQ);
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 339 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETLOD);
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 340 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CONV);
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 341 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CONVM);
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 342 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETSIZE);
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 343 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETBUF);
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 344 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETPOS);
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 345 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETINFO);
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 346 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DSX);
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 347 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DSY);
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 348 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GATHER4R);
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 349 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GATHER4G);
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 350 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GATHER4B);
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 351 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GATHER4A);
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 352 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAMGP0);
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 353 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAMGP1);
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 354 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAMGP2);
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 355 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SAMGP3);
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 356 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DSXPP_1);
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 357 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DSYPP_1);
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 358 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RGETPOS);
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 359 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RGETINFO);
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 360 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BRCST_A);
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 361 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_QSHUFFLE_BRCST);
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 362 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_QSHUFFLE_H);
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 363 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_QSHUFFLE_V);
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 364 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_QSHUFFLE_DIAG);
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 365 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_TCINV);
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 366 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_IMG_BINDLESS_HOF);
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 367 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_IMG_BINDLESS_PCMN);
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 368 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_IMG_BINDLESS);
	YY_BREAK
/* category 6: */
case 234:
YY_RULE_SETUP
#line 371 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDG);
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 372 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDG_A);
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 373 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDG_K);
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 374 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDL);
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 375 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDP);
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 376 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STG);
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 377 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STG_A);
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 378 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STL);
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 379 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STP);
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 380 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDIB);
	YY_BREAK
case 244:
YY_RULE_SETUP
#line 381 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_G2L);
	YY_BREAK
case 245:
YY_RULE_SETUP
#line 382 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_L2G);
	YY_BREAK
case 246:
YY_RULE_SETUP
#line 383 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_PREFETCH);
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 384 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDLW);
	YY_BREAK
case 248:
YY_RULE_SETUP
#line 385 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STLW);
	YY_BREAK
case 249:
YY_RULE_SETUP
#line 386 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RESFMT);
	YY_BREAK
case 250:
YY_RULE_SETUP
#line 387 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RESINFO);
	YY_BREAK
case 251:
YY_RULE_SETUP
#line 388 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RESBASE);
	YY_BREAK
case 252:
YY_RULE_SETUP
#line 389 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_ADD);
	YY_BREAK
case 253:
YY_RULE_SETUP
#line 390 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_SUB);
	YY_BREAK
case 254:
YY_RULE_SETUP
#line 391 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_XCHG);
	YY_BREAK
case 255:
YY_RULE_SETUP
#line 392 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_INC);
	YY_BREAK
case 256:
YY_RULE_SETUP
#line 393 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_DEC);
	YY_BREAK
case 257:
YY_RULE_SETUP
#line 394 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_CMPXCHG);
	YY_BREAK
case 258:
YY_RULE_SETUP
#line 395 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_MIN);
	YY_BREAK
case 259:
YY_RULE_SETUP
#line 396 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_MAX);
	YY_BREAK
case 260:
YY_RULE_SETUP
#line 397 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_AND);
	YY_BREAK
case 261:
YY_RULE_SETUP
#line 398 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_OR);
	YY_BREAK
case 262:
YY_RULE_SETUP
#line 399 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_XOR);
	YY_BREAK
case 263:
YY_RULE_SETUP
#line 400 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RESINFO_B);
	YY_BREAK
case 264:
YY_RULE_SETUP
#line 401 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDIB_B);
	YY_BREAK
case 265:
YY_RULE_SETUP
#line 402 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STIB_B);
	YY_BREAK
case 266:
YY_RULE_SETUP
#line 403 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_ADD);
	YY_BREAK
case 267:
YY_RULE_SETUP
#line 404 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_SUB);
	YY_BREAK
case 268:
YY_RULE_SETUP
#line 405 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_XCHG);
	YY_BREAK
case 269:
YY_RULE_SETUP
#line 406 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_INC);
	YY_BREAK
case 270:
YY_RULE_SETUP
#line 407 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_DEC);
	YY_BREAK
case 271:
YY_RULE_SETUP
#line 408 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_CMPXCHG);
	YY_BREAK
case 272:
YY_RULE_SETUP
#line 409 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_MIN);
	YY_BREAK
case 273:
YY_RULE_SETUP
#line 410 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_MAX);
	YY_BREAK
case 274:
YY_RULE_SETUP
#line 411 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_AND);
	YY_BREAK
case 275:
YY_RULE_SETUP
#line 412 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_OR);
	YY_BREAK
case 276:
YY_RULE_SETUP
#line 413 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_B_XOR);
	YY_BREAK
case 277:
YY_RULE_SETUP
#line 414 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_ADD);
	YY_BREAK
case 278:
YY_RULE_SETUP
#line 415 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_SUB);
	YY_BREAK
case 279:
YY_RULE_SETUP
#line 416 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_XCHG);
	YY_BREAK
case 280:
YY_RULE_SETUP
#line 417 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_INC);
	YY_BREAK
case 281:
YY_RULE_SETUP
#line 418 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_DEC);
	YY_BREAK
case 282:
YY_RULE_SETUP
#line 419 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_CMPXCHG);
	YY_BREAK
case 283:
YY_RULE_SETUP
#line 420 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_MIN);
	YY_BREAK
case 284:
YY_RULE_SETUP
#line 421 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_MAX);
	YY_BREAK
case 285:
YY_RULE_SETUP
#line 422 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_AND);
	YY_BREAK
case 286:
YY_RULE_SETUP
#line 423 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_OR);
	YY_BREAK
case 287:
YY_RULE_SETUP
#line 424 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_S_XOR);
	YY_BREAK
case 288:
YY_RULE_SETUP
#line 425 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_ADD);
	YY_BREAK
case 289:
YY_RULE_SETUP
#line 426 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_SUB);
	YY_BREAK
case 290:
YY_RULE_SETUP
#line 427 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_XCHG);
	YY_BREAK
case 291:
YY_RULE_SETUP
#line 428 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_INC);
	YY_BREAK
case 292:
YY_RULE_SETUP
#line 429 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_DEC);
	YY_BREAK
case 293:
YY_RULE_SETUP
#line 430 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_CMPXCHG);
	YY_BREAK
case 294:
YY_RULE_SETUP
#line 431 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_MIN);
	YY_BREAK
case 295:
YY_RULE_SETUP
#line 432 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_MAX);
	YY_BREAK
case 296:
YY_RULE_SETUP
#line 433 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_AND);
	YY_BREAK
case 297:
YY_RULE_SETUP
#line 434 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_OR);
	YY_BREAK
case 298:
YY_RULE_SETUP
#line 435 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ATOMIC_G_XOR);
	YY_BREAK
case 299:
YY_RULE_SETUP
#line 437 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDGB);
	YY_BREAK
case 300:
YY_RULE_SETUP
#line 438 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STGB);
	YY_BREAK
case 301:
YY_RULE_SETUP
#line 439 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STIB);
	YY_BREAK
case 302:
YY_RULE_SETUP
#line 440 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDC);
	YY_BREAK
case 303:
YY_RULE_SETUP
#line 441 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LDLV);
	YY_BREAK
case 304:
YY_RULE_SETUP
#line 442 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETSPID);
	YY_BREAK
case 305:
YY_RULE_SETUP
#line 443 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETWID);
	YY_BREAK
case 306:
YY_RULE_SETUP
#line 444 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_GETFIBERID);
	YY_BREAK
case 307:
YY_RULE_SETUP
#line 445 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STC);
	YY_BREAK
case 308:
YY_RULE_SETUP
#line 446 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_STSC);
	YY_BREAK
case 309:
YY_RULE_SETUP
#line 447 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SHFL);
	YY_BREAK
case 310:
YY_RULE_SETUP
#line 449 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_RAY_INTERSECTION);
	YY_BREAK
/* category 7: */
case 311:
YY_RULE_SETUP
#line 452 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_BAR);
	YY_BREAK
case 312:
YY_RULE_SETUP
#line 453 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_FENCE);
	YY_BREAK
case 313:
YY_RULE_SETUP
#line 454 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_SLEEP);
	YY_BREAK
case 314:
YY_RULE_SETUP
#line 455 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ICINV);
	YY_BREAK
case 315:
YY_RULE_SETUP
#line 456 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DCCLN);
	YY_BREAK
case 316:
YY_RULE_SETUP
#line 457 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DCINV);
	YY_BREAK
case 317:
YY_RULE_SETUP
#line 458 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_DCFLU);
	YY_BREAK
case 318:
YY_RULE_SETUP
#line 459 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_CCINV);
	YY_BREAK
case 319:
YY_RULE_SETUP
#line 460 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_LOCK);
	YY_BREAK
case 320:
YY_RULE_SETUP
#line 461 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_UNLOCK);
	YY_BREAK
case 321:
YY_RULE_SETUP
#line 462 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_ALIAS);
	YY_BREAK
case 322:
YY_RULE_SETUP
#line 464 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_OP_PRINT);
	YY_BREAK
case 323:
YY_RULE_SETUP
#line 466 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_F16);
	YY_BREAK
case 324:
YY_RULE_SETUP
#line 467 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_F32);
	YY_BREAK
case 325:
YY_RULE_SETUP
#line 468 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_U16);
	YY_BREAK
case 326:
YY_RULE_SETUP
#line 469 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_U32);
	YY_BREAK
case 327:
YY_RULE_SETUP
#line 470 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_S16);
	YY_BREAK
case 328:
YY_RULE_SETUP
#line 471 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_S32);
	YY_BREAK
case 329:
YY_RULE_SETUP
#line 472 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_U8);
	YY_BREAK
case 330:
YY_RULE_SETUP
#line 473 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_U8_32);
	YY_BREAK
case 331:
YY_RULE_SETUP
#line 474 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_U64);
	YY_BREAK
case 332:
YY_RULE_SETUP
#line 475 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_B16);
	YY_BREAK
case 333:
YY_RULE_SETUP
#line 476 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPE_B32);
	YY_BREAK
case 334:
YY_RULE_SETUP
#line 478 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_UNTYPED);
	YY_BREAK
case 335:
YY_RULE_SETUP
#line 479 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_TYPED);
	YY_BREAK
case 336:
YY_RULE_SETUP
#line 481 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_UNSIGNED);
	YY_BREAK
case 337:
YY_RULE_SETUP
#line 482 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_MIXED);
	YY_BREAK
case 338:
YY_RULE_SETUP
#line 483 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_LOW);
	YY_BREAK
case 339:
YY_RULE_SETUP
#line 484 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_HIGH);
	YY_BREAK
case 340:
YY_RULE_SETUP
#line 486 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_1D);
	YY_BREAK
case 341:
YY_RULE_SETUP
#line 487 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_2D);
	YY_BREAK
case 342:
YY_RULE_SETUP
#line 488 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_3D);
	YY_BREAK
case 343:
YY_RULE_SETUP
#line 489 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_4D);
	YY_BREAK
case 344:
YY_RULE_SETUP
#line 491 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_SAD);
	YY_BREAK
case 345:
YY_RULE_SETUP
#line 492 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_SSD);
	YY_BREAK
case 346:
YY_RULE_SETUP
#line 494 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_LT);
	YY_BREAK
case 347:
YY_RULE_SETUP
#line 495 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_LE);
	YY_BREAK
case 348:
YY_RULE_SETUP
#line 496 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_GT);
	YY_BREAK
case 349:
YY_RULE_SETUP
#line 497 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_GE);
	YY_BREAK
case 350:
YY_RULE_SETUP
#line 498 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_EQ);
	YY_BREAK
case 351:
YY_RULE_SETUP
#line 499 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_NE);
	YY_BREAK
case 352:
YY_RULE_SETUP
#line 501 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'a';
	YY_BREAK
case 353:
YY_RULE_SETUP
#line 502 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'o';
	YY_BREAK
case 354:
YY_RULE_SETUP
#line 503 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'p';
	YY_BREAK
case 355:
YY_RULE_SETUP
#line 504 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_S2EN);
	YY_BREAK
case 356:
YY_RULE_SETUP
#line 505 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 's';
	YY_BREAK
case 357:
YY_RULE_SETUP
#line 506 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'k';
	YY_BREAK
case 358:
YY_RULE_SETUP
#line 507 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'u';
	YY_BREAK
case 359:
YY_RULE_SETUP
#line 508 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'v';
	YY_BREAK
case 360:
YY_RULE_SETUP
#line 509 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_RCK;
	YY_BREAK
case 361:
YY_RULE_SETUP
#line 510 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_CLP;
	YY_BREAK
case 362:
YY_RULE_SETUP
#line 511 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtol(yytext+4, NULL, 10); return T_BASE;
	YY_BREAK
case 363:
YY_RULE_SETUP
#line 512 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.num = strtol(yytext+6, NULL, 10); return T_OFFSET;
	YY_BREAK
case 364:
YY_RULE_SETUP
#line 513 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_UNIFORM;
	YY_BREAK
case 365:
YY_RULE_SETUP
#line 514 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_NONUNIFORM;
	YY_BREAK
case 366:
YY_RULE_SETUP
#line 515 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_IMM;
	YY_BREAK
case 367:
YY_RULE_SETUP
#line 517 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_TEX;
	YY_BREAK
case 368:
YY_RULE_SETUP
#line 518 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_MEM;
	YY_BREAK
case 369:
YY_RULE_SETUP
#line 519 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_RT;
	YY_BREAK
case 370:
YY_RULE_SETUP
#line 521 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_XOR;
	YY_BREAK
case 371:
YY_RULE_SETUP
#line 522 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_UP;
	YY_BREAK
case 372:
YY_RULE_SETUP
#line 523 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_DOWN;
	YY_BREAK
case 373:
YY_RULE_SETUP
#line 524 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_RUP;
	YY_BREAK
case 374:
YY_RULE_SETUP
#line 525 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return T_MOD_RDOWN;
	YY_BREAK
case 375:
YY_RULE_SETUP
#line 527 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'h';
	YY_BREAK
case 376:
YY_RULE_SETUP
#line 528 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '=';
	YY_BREAK
case 377:
YY_RULE_SETUP
#line 529 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '(';
	YY_BREAK
case 378:
YY_RULE_SETUP
#line 530 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return ')';
	YY_BREAK
case 379:
YY_RULE_SETUP
#line 531 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '[';
	YY_BREAK
case 380:
YY_RULE_SETUP
#line 532 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return ']';
	YY_BREAK
case 381:
YY_RULE_SETUP
#line 533 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return ',';
	YY_BREAK
case 382:
YY_RULE_SETUP
#line 534 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '.';
	YY_BREAK
case 383:
YY_RULE_SETUP
#line 535 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '-';
	YY_BREAK
case 384:
YY_RULE_SETUP
#line 536 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '+';
	YY_BREAK
case 385:
YY_RULE_SETUP
#line 537 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '|';
	YY_BREAK
case 386:
YY_RULE_SETUP
#line 538 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'c';
	YY_BREAK
case 387:
YY_RULE_SETUP
#line 539 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'r';
	YY_BREAK
case 388:
YY_RULE_SETUP
#line 540 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_HC);
	YY_BREAK
case 389:
YY_RULE_SETUP
#line 541 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_HR);
	YY_BREAK
case 390:
YY_RULE_SETUP
#line 542 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'g';
	YY_BREAK
case 391:
YY_RULE_SETUP
#line 543 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'w';
	YY_BREAK
case 392:
YY_RULE_SETUP
#line 544 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return 'l';
	YY_BREAK
case 393:
YY_RULE_SETUP
#line 545 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '<';
	YY_BREAK
case 394:
YY_RULE_SETUP
#line 546 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '>';
	YY_BREAK
case 395:
YY_RULE_SETUP
#line 547 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '!';
	YY_BREAK
case 396:
YY_RULE_SETUP
#line 548 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return '#';
	YY_BREAK
case 397:
YY_RULE_SETUP
#line 549 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return ':';
	YY_BREAK
case 398:
YY_RULE_SETUP
#line 551 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_NAN);
	YY_BREAK
case 399:
YY_RULE_SETUP
#line 552 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
return TOKEN(T_INF);
	YY_BREAK
case 400:
YY_RULE_SETUP
#line 554 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ir3_yylval.str = ralloc_strdup(ir3_parser_dead_ctx, yytext); return T_IDENTIFIER;
	YY_BREAK
case 401:
YY_RULE_SETUP
#line 555 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
fprintf(stderr, "error at line %d: Unknown token: %s\n", ir3_yyget_lineno(), yytext); yyterminate();
	YY_BREAK
case 402:
YY_RULE_SETUP
#line 556 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"
ECHO;
	YY_BREAK
#line 3846 "src/freedreno/ir3/ir3_lexer.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1229 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1229 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1228);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 556 "../mesa-26.1.1/src/freedreno/ir3/ir3_lexer.l"


